"""Markdown configuration file management.

Provides Markdown documentation files: README.md (project name header + badges),
CODE_OF_CONDUCT.md (community standards), CONTRIBUTING.md (contribution
guidelines), SECURITY.md (vulnerability reporting), pull_request_template.md
(PR template), and MkDocs pages (docs/index.md, docs/api.md).

Modules:
    readme: README.md configuration management
    code_of_conduct: CODE_OF_CONDUCT.md configuration management
    contributing: CONTRIBUTING.md configuration management
    security: SECURITY.md configuration management
    pull_request_template: Pull request template configuration management
    docs: MkDocs documentation files (index.md, api.md)

See Also:
    pyrig.dev.configs.base.badges_md.BadgesMarkdownConfigFile
    pyrig.dev.configs.docs.mkdocs.MkdocsConfigFile
"""
